require 'gem2deb/rake/spectask'

Gem2Deb::Rake::RSpecTask.new do |spec|
  spec.pattern = FileList["spec/**/*_spec.rb"] - FileList["spec/formatters/lines_spec.rb", "spec/formatters/logstash_spec.rb"]
end
